@@ -264,7 +264,7 @@ class ModelConverter:
                 if hasattr(data_type, "impl"):
                     return self._get_field_class_for_data_type(data_type.impl)
                 raise ModelConversionError(
-                    "Could not find field column of type {}.".format(types[0])
+                    f"Could not find field column of type {types[0]}."
                 )
         return field_cls
 
@@ -313,17 +313,22 @@ class ModelConverter:
         """Add keyword arguments to kwargs (in-place) based on the passed in
         `Column <sqlalchemy.schema.Column>`.
         """
-        if column.nullable:
-            kwargs["allow_none"] = True
-        kwargs["required"] = not column.nullable and not _has_default(column)
+        if hasattr(column, "nullable"):
+            if column.nullable:
+                kwargs["allow_none"] = True
+            kwargs["required"] = not column.nullable and not _has_default(column)
+        # If there is no nullable attribute, we are dealing with a property
+        # that does not derive from the Column class. Mark as dump_only.
+        else:
+            kwargs["dump_only"] = True
 
-        if hasattr(column.type, "enums"):
+        if hasattr(column.type, "enums") and not kwargs.get("dump_only"):
             kwargs["validate"].append(validate.OneOf(choices=column.type.enums))
 
         # Add a length validator if a max length is set on the column
         # Skip UUID columns
         # (see https://github.com/marshmallow-code/marshmallow-sqlalchemy/issues/54)
-        if hasattr(column.type, "length"):
+        if hasattr(column.type, "length") and not kwargs.get("dump_only"):
             column_length = column.type.length
             if column_length is not None:
                 try:
